searchData={"items":[{"type":"behaviour","title":"Late","doc":"","ref":"Late.html"},{"type":"behaviour","title":"Example - Late","doc":"defmodule MyConnection do\n      @behaviour Late\n\n      @impl true\n      def init(_args) do\n        {:ok, %{from: nil}}\n      end\n\n      @impl true\n      def handle_call({:something, query}, from, state) do\n        {:noreply, stuff}\n      end\n\n      @impl true\n      def handle_in({:text, text}, state) do\n        {:reply, [frame], new_state}\n      end\n    end","ref":"Late.html#module-example"},{"type":"function","title":"Late.call/3","doc":"Calls the given server.\n\nWrapper for `:gen_statem.call/3`.","ref":"Late.html#call/3"},{"type":"callback","title":"Late.handle_call/3","doc":"Invoked when the server receives a call message sent by `Late.call/3`.\n\nYou must reply to the calling process using `Late.reply/2`.\nReturning a `{:reply, [frame], state}` tuple will send the frames to the WebSocket server,\nnot the calling process.","ref":"Late.html#c:handle_call/3"},{"type":"callback","title":"Late.handle_connect/2","doc":"Invoked after connecting or reconnecting.","ref":"Late.html#c:handle_connect/2"},{"type":"callback","title":"Late.handle_disconnect/2","doc":"Invoked after disconnecting.","ref":"Late.html#c:handle_disconnect/2"},{"type":"callback","title":"Late.handle_in/2","doc":"Invoked when the server receives a WebSocket frame.","ref":"Late.html#c:handle_in/2"},{"type":"callback","title":"Late.handle_info/2","doc":"Invoked when the server receives any message that is not a call or WebSocket frame.","ref":"Late.html#c:handle_info/2"},{"type":"callback","title":"Late.init/1","doc":"","ref":"Late.html#c:init/1"},{"type":"function","title":"Late.reply/2","doc":"Replies to the given `Late.call/3` caller.\n\nWrapper for `:gen_statem.reply/2`.","ref":"Late.html#reply/2"},{"type":"function","title":"Late.start_link/3","doc":"","ref":"Late.html#start_link/3"},{"type":"type","title":"Late.call_result/0","doc":"","ref":"Late.html#t:call_result/0"},{"type":"type","title":"Late.disconnect_reason/0","doc":"","ref":"Late.html#t:disconnect_reason/0"},{"type":"type","title":"Late.frame/0","doc":"","ref":"Late.html#t:frame/0"},{"type":"type","title":"Late.state/0","doc":"","ref":"Late.html#t:state/0"},{"type":"extras","title":"Introduction","doc":"# Late\n\n[![Documentation badge](https://img.shields.io/badge/Hexdocs-ff6900)](https://hexdocs.pm/late/)\n[![Hex.pm badge](https://img.shields.io/badge/hex.pm-informational)](https://hex.pm/packages/late)\n\nLate is a websocket client library for Elixir using Mint and `:gen_statem`.\n\nIt features a simple design, synchronous and synchronous calls and handling connection errors during process init instead of after startup.","ref":"readme.html"},{"type":"extras","title":"Usage - Introduction","doc":"```elixir\ndefmodule TestConnection do\n  @behaviour Late\n\n  require Logger\n\n  def send_sync(pid, message) do\n    Late.call(pid, {:send, message})\n  end\n\n  def send_async(pid, message) do\n    Process.send(pid, message, [])\n  end\n\n  @impl true\n  def init(_opts) do\n    {:ok, 0}\n  end\n\n  @impl true\n  def handle_connect(state) do\n    Logger.info(\"Connected\")\n    {:reply, {:text, \"hi\"}, state}\n  end\n\n  @impl true\n  def handle_disconnect(state, reason) do\n    Logger.info(\"Disconnected! #{inspect reason}\")\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_call({:send, msg}, from, state) do\n    Late.reply(from, :ok)\n    {:reply, {:text, msg}, state}\n  end\n\n  @impl true\n  def handle_in({:text, \"bye\"}, state) do\n    {:stop, state}\n  end\n\n  def handle_in({:text, msg}, state) do\n    Logger.info(\"Received message #{inspect msg}\")\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_info(message, state) do\n    {:reply, [{:text, \"message one\"}, {:text, message}], state}\n  end\nend\n\n{:ok, pid} = Late.start_link(\n  TestConnection,\n  [],\n  url: \"ws://localhost:3000/websocket\"\n)\n\n:ok = TestConnection.send_sync(pid, \"hello\")\n:ok = TestConnection.send_async(pid, \"Send this message asynchronously\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Introduction","doc":"```elixir\n{:late, \"~> 0.3.0\"},\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}